summaryrefslogtreecommitdiffstats
path: root/kalyptus/kalyptusCxxToKimono.pm
diff options
context:
space:
mode:
Diffstat (limited to 'kalyptus/kalyptusCxxToKimono.pm')
-rw-r--r--kalyptus/kalyptusCxxToKimono.pm46
1 files changed, 23 insertions, 23 deletions
diff --git a/kalyptus/kalyptusCxxToKimono.pm b/kalyptus/kalyptusCxxToKimono.pm
index bdf4f6d..089cec9 100644
--- a/kalyptus/kalyptusCxxToKimono.pm
+++ b/kalyptus/kalyptusCxxToKimono.pm
@@ -79,9 +79,9 @@ BEGIN
'char*' => '$',
'TQCOORD*' => '?',
'TQRgb*' => '?',
- 'Q_UINT64' => '$',
- 'Q_INT64' => '$',
- 'Q_LLONG' => '$',
+ 'TQ_UINT64' => '$',
+ 'TQ_INT64' => '$',
+ 'TQ_LLONG' => '$',
'tquint64' => '$',
'qint64' => '$',
'long long' => '$',
@@ -146,21 +146,21 @@ BEGIN
'TQEventLoop::ProcessEventsFlags' => 'uint',
'TQStyle::SCFlags' => 'int',
'TQStyle::SFlags' => 'int',
- 'Q_INT16' => 'short',
+ 'TQ_INT16' => 'short',
'qint16' => 'short',
- 'Q_INT32' => 'int',
+ 'TQ_INT32' => 'int',
'qint32' => 'int',
'qint32&' => 'int&',
- 'Q_INT8' => 'char',
+ 'TQ_INT8' => 'char',
'qint8' => 'char',
- 'Q_LONG' => 'long',
- 'Q_UINT16' => 'ushort',
+ 'TQ_LONG' => 'long',
+ 'TQ_UINT16' => 'ushort',
'tquint16' => 'ushort',
- 'Q_UINT32' => 'uint',
+ 'TQ_UINT32' => 'uint',
'tquint32' => 'uint',
- 'Q_UINT8' => 'uchar',
+ 'TQ_UINT8' => 'uchar',
'tquint8' => 'uchar',
- 'Q_ULONG' => 'long',
+ 'TQ_ULONG' => 'long',
'qreal' => 'double',
'pid_t' => 'int',
'size_t' => 'int',
@@ -553,18 +553,18 @@ sub cplusplusToCSharp
|| kalyptusDataDict::ctypemap($cplusplusType) =~ /qt_QVariantValueList\s*\*/
|| kalyptusDataDict::ctypemap($cplusplusType) =~ /qt_QIconDragItemValueList\s*\*/
|| kalyptusDataDict::ctypemap($cplusplusType) =~ /qt_QPixmapValueList\s*\*/
- || kalyptusDataDict::ctypemap($cplusplusType) =~ /kde_QCStringList\s*\*/
+ || kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_QCStringList\s*\*/
|| kalyptusDataDict::ctypemap($cplusplusType) =~ /qt_QObjectList\s*\*/
|| kalyptusDataDict::ctypemap($cplusplusType) =~ /qt_QDomNodeList\s*\*/
|| kalyptusDataDict::ctypemap($cplusplusType) =~ /qt_QWidgetList\s*\*/
- || kalyptusDataDict::ctypemap($cplusplusType) =~ /kde_KURLList\s*\*/
- || kalyptusDataDict::ctypemap($cplusplusType) =~ /kde_TDEMainWindow\s*\*/
- || kalyptusDataDict::ctypemap($cplusplusType) =~ /kde_KFileItemList\s*\*/
- || kalyptusDataDict::ctypemap($cplusplusType) =~ /kde_KFileViewItemList\s*\*/
- || kalyptusDataDict::ctypemap($cplusplusType) =~ /kde_DOMNodeList\s*\*/
- || kalyptusDataDict::ctypemap($cplusplusType) =~ /kde_StyleSheetList\s*\*/
- || kalyptusDataDict::ctypemap($cplusplusType) =~ /kde_MediaList\s*\*/
- || kalyptusDataDict::ctypemap($cplusplusType) =~ /kde_OfferList\s*\*/
+ || kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_KURLList\s*\*/
+ || kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_TDEMainWindow\s*\*/
+ || kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_KFileItemList\s*\*/
+ || kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_KFileViewItemList\s*\*/
+ || kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_DOMNodeList\s*\*/
+ || kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_StyleSheetList\s*\*/
+ || kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_MediaList\s*\*/
+ || kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_OfferList\s*\*/
|| $cplusplusType =~ /TQMemArray<TQRect>/
|| kalyptusDataDict::ctypemap($cplusplusType) =~ /qt_QCanvasItemList\s*\*/ ) {
return "ArrayList"
@@ -588,7 +588,7 @@ sub cplusplusToCSharp
} else {
return $1;
}
- } elsif ( kalyptusDataDict::ctypemap($cplusplusType) =~ /kde_([^\*\s]*)(.*)$/ and !$skippedClasses{$className}) {
+ } elsif ( kalyptusDataDict::ctypemap($cplusplusType) =~ /tde_([^\*\s]*)(.*)$/ and !$skippedClasses{$className}) {
if ( defined interfaceForClass($1) ) {
return interfaceForClass($1);
} else {
@@ -1150,7 +1150,7 @@ sub writeClassDoc
# my $fileName = join( "__", kdocAstUtil::heritage($node) );
print "Enter: $className\n" if $debug;
- my $typeprefix = ($className =~ /^Q/ ? "qt_" : "kde_");
+ my $typeprefix = ($className =~ /^Q/ ? "qt_" : "tde_");
my $packagename = ($typeprefix eq 'qt_' ? "Qt" : "KDE");
# Write out the *.csharp file
@@ -2585,7 +2585,7 @@ sub registerType($$) {
}
# Apply typedefs, and store the resulting type.
# For instance, if $type was Q_UINT16&, realType will be ushort
$allTypes{$type}{realType} = applyTypeDef( $realType );
# In the first phase we only create entries into allTypes.
@@ -2585,7 +2585,7 @@ sub registerType($$) {
}
# Apply typedefs, and store the resulting type.
- # For instance, if $type was Q_UINT16&, realType will be ushort
+ # For instance, if $type was TQ_UINT16&, realType will be ushort
$allTypes{$type}{realType} = applyTypeDef( $realType );
# In the first phase we only create entries into allTypes.